#ifndef NT2_CORE_INCLUDE_FUNCTIONS_FINDI_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_FINDI_HPP_INCLUDED

#include <nt2/core/functions/findi.hpp>
#include <nt2/core/functions/expr/findi.hpp>

#endif
